<?xml version='1.0' encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format" version="1.1">
    <xsl:import href="p_docbook_common-default.xsl"/>
    <xsl:output encoding="UTF-8" indent="no" method="xml"/>
    
    <xsl:template name="header.content">
        <xsl:param name="pageclass" select="''"/>
        <xsl:param name="sequence" select="''"/>
        <xsl:param name="position" select="''"/>
        <xsl:param name="gentext-key" select="''"/>
        
        <xsl:variable name="candidate">
            <xsl:choose>
                <xsl:when test="$sequence = 'odd' and $position = 'left'">
                    <xsl:apply-templates select="." mode="object.title.markup"/>
                </xsl:when>
                <xsl:when test="$sequence = 'odd' and $position = 'right'">
                    <fo:page-number/>
                </xsl:when>
                
                <xsl:when test="$sequence = 'even' and $position = 'left'">
                    <fo:page-number/>
                </xsl:when>
                
                <xsl:when test="$sequence = 'even' and $position = 'right'">
                    <xsl:apply-templates select="." mode="object.title.markup"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$sequence='blank' and $headers.on.blank.pages=0"> </xsl:when>
            <xsl:otherwise>
                <xsl:copy-of select="$candidate"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="fh_author">
        <xsl:choose>
            <xsl:when test="count(othername) and count(firstname) = 0">
                <xsl:value-of select="othername"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="firstname"/>
                <xsl:if test="count(lineage)">
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="lineage"/>
                </xsl:if>
                <xsl:text> </xsl:text>
                <xsl:value-of select="surname"/>
                <xsl:if test="count(othername)">
                    <xsl:text> &quot;</xsl:text>
                    <xsl:value-of select="othername"/>
                    <xsl:text>&quot;</xsl:text>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="fh_authors">
        <xsl:choose>
            <xsl:when test="count(ancestor-or-self::book/bookinfo/author)">
                <xsl:for-each select="ancestor-or-self::book/bookinfo/author[position() = 1]">
                    <xsl:call-template name="fh_author"/>
                </xsl:for-each>
            </xsl:when>
            <xsl:when test="count(ancestor-or-self::book/bookinfo/authorgroup)">
                <xsl:for-each
                    select="ancestor-or-self::book/bookinfo/authorgroup/author[position() = 1]">
                    <xsl:call-template name="fh_author"/>
                </xsl:for-each>
                <xsl:for-each
                    select="ancestor-or-self::book/bookinfo/authorgroup/author[position() = 2]">
                    <xsl:text xml:space="preserve">; </xsl:text>
                    <xsl:call-template name="fh_author"/>
                </xsl:for-each>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="footer.content">
        <xsl:param name="pageclass" select="''"/>
        <xsl:param name="sequence" select="''"/>
        <xsl:param name="position" select="''"/>
        <xsl:param name="gentext-key" select="''"/>
        
        <xsl:variable name="candidate">
            <xsl:choose>
                <xsl:when test="$sequence = 'odd' and $position = 'left'">
                    <xsl:value-of select="ancestor-or-self::book/bookinfo/title"/>
                </xsl:when>
                <xsl:when test="$sequence = 'odd' and $position = 'right'">
                    <xsl:call-template name="fh_authors"/>
                </xsl:when>
                <xsl:when test="$sequence = 'even' and $position = 'right'">
                    <xsl:value-of select="ancestor-or-self::book/bookinfo/title"/>
                </xsl:when>
                <xsl:when test="$sequence = 'even' and $position = 'left'">
                    <xsl:call-template name="fh_authors"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:choose>
            <xsl:when test="$sequence='blank' and $headers.on.blank.pages=0"> </xsl:when>
            <xsl:otherwise>
                <xsl:copy-of select="$candidate"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:attribute-set name="root.properties">
        <xsl:attribute name="font-family">
            <xsl:value-of select="$body.fontset"/>
        </xsl:attribute>
        <xsl:attribute name="color">rgb(0, 0, 0)</xsl:attribute>
        <xsl:attribute name="font-size">
            <xsl:value-of select="$body.font.size"/>
        </xsl:attribute>
        <xsl:attribute name="text-align">
            <xsl:value-of select="$alignment"/>
        </xsl:attribute>
        <xsl:attribute name="line-height">
            <xsl:value-of select="$line-height"/>
        </xsl:attribute>
        <xsl:attribute name="font-selection-strategy">character-by-character</xsl:attribute>
        <xsl:attribute name="line-height-shift-adjustment">disregard-shifts</xsl:attribute>
    </xsl:attribute-set>

    <!--xsl:variable name="poem.text-indent" select="'0pt'"/-->
    <xsl:variable name="p.text-indent" select="'6%'"/>

    <xsl:attribute-set name="normal.para.spacing">
        <xsl:attribute name="start-indent">0pt</xsl:attribute>
        <xsl:attribute name="text-indent">
            <xsl:choose>
                <xsl:when test="@role = 'p'">
                    <xsl:value-of select="$p.text-indent"/>
                </xsl:when>
                <xsl:otherwise>0pt</xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="blockquote.properties">
        <xsl:attribute name="text-align">right</xsl:attribute>
        <xsl:attribute name="font-style">italic</xsl:attribute>
        <xsl:attribute name="start-indent">0pt</xsl:attribute>
        <xsl:attribute name="text-indent">0pt</xsl:attribute>
        <xsl:attribute name="margin-right">0pt</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="formal.title.properties" use-attribute-sets="normal.para.spacing">
        <xsl:attribute name="font-weight">bold</xsl:attribute>
        <xsl:attribute name="font-size">
            <xsl:value-of select="$body.font.master * 1.2"/>
            <xsl:text>pt</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="hyphenate">false</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="verbatim.properties">
        <xsl:attribute name="text-align">start</xsl:attribute>
        <xsl:attribute name="hyphenate">false</xsl:attribute>
        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
        <xsl:attribute name="white-space-collapse">false</xsl:attribute>
        <xsl:attribute name="white-space-treatment">preserve</xsl:attribute>
        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="formal.object.properties">
        <xsl:attribute name="keep-together.within-column">always</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="informal.object.properties"> </xsl:attribute-set>
</xsl:stylesheet>
