<?xml version='1.0' encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format" version="1.1">
    <xsl:import href="p_docbook_common-default.xsl"/>
    <xsl:output encoding="UTF-8" indent="no" method="xml"/>
    <xsl:template name="footer.content"/>
    <xsl:template name="header.content"/>
    
    <xsl:attribute-set name="root.properties">
        <xsl:attribute name="font-family">
            <xsl:value-of select="$body.fontset"/>
        </xsl:attribute>
        <xsl:attribute name="color">rgb(0, 0, 0)</xsl:attribute> 
        <xsl:attribute name="font-size">
            <xsl:value-of select="$body.font.size"/>
        </xsl:attribute>
        <xsl:attribute name="text-align">
            <xsl:value-of select="$alignment"/>
        </xsl:attribute>
        <xsl:attribute name="line-height">
            <xsl:value-of select="$line-height"/>
        </xsl:attribute>
        <xsl:attribute name="font-selection-strategy">character-by-character</xsl:attribute>
        <xsl:attribute name="line-height-shift-adjustment">disregard-shifts</xsl:attribute>
    </xsl:attribute-set>
    
    <!-- Расскоментировать, чтобы отключить расстановку переносов для всех элементов.
        Для конкретных см. как отключаются для всех title в стилях. -->
    <!--xsl:param name="hyphenate">false</xsl:param-->
    
    <!-- Отключение сепаратора перед обложкой, не особо нужно, только если есть набор книг (set). -->    
    <!--xsl:template name="book.titlepage.before.verso"/-->
    
    <!-- Выключение первой страницы обложки -->    
    <!--xsl:template name="book.titlepage.recto"/-->
    
    <!-- Выключение сепаратора после информации о книге (обложки) -->
    <xsl:template name="book.titlepage.separator"/>
    
    <!-- Центрировать названия компонентных частей книги: part, chapter и др. -->
    <xsl:attribute-set name="component.title.properties">
        <xsl:attribute name="text-align">center</xsl:attribute>
    </xsl:attribute-set>
    
    <!-- Центрировать названия секций -->
    <xsl:attribute-set name="section.title.properties">
        <xsl:attribute name="text-align">center</xsl:attribute>
    </xsl:attribute-set>
    
    <xsl:variable name="p.text-indent" select="'10%'"/>
    
    <xsl:attribute-set name="normal.para.spacing">
        <xsl:attribute name="start-indent">0pt</xsl:attribute>
        <xsl:attribute name="text-indent">
            <xsl:choose>
                <xsl:when test="@role = 'p'">
                    <xsl:value-of select="$p.text-indent"/>
                </xsl:when>
                <xsl:otherwise>0pt</xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
        <xsl:attribute name="space-before.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.maximum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.maximum">0.2em</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="blockquote.properties">
        <xsl:attribute name="text-align">right</xsl:attribute>
        <xsl:attribute name="font-style">italic</xsl:attribute>
        <xsl:attribute name="start-indent">0pt</xsl:attribute>
        <xsl:attribute name="text-indent">0pt</xsl:attribute>
        <xsl:attribute name="margin-right">0pt</xsl:attribute>
        <xsl:attribute name="space-before.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.maximum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.maximum">0.2em</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="formal.title.properties" use-attribute-sets="normal.para.spacing">
        <xsl:attribute name="font-weight">bold</xsl:attribute>
        <xsl:attribute name="font-size">
            <xsl:value-of select="$body.font.master * 1.2"/>
            <xsl:text>pt</xsl:text>
        </xsl:attribute>
        <xsl:attribute name="hyphenate">false</xsl:attribute>
        <xsl:attribute name="space-after.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.maximum">0.2em</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="verbatim.properties">
        <xsl:attribute name="space-before.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.maximum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.maximum">0.2em</xsl:attribute>
        <xsl:attribute name="text-align">start</xsl:attribute>
        <xsl:attribute name="hyphenate">false</xsl:attribute>
        <xsl:attribute name="wrap-option">no-wrap</xsl:attribute>
        <xsl:attribute name="white-space-collapse">false</xsl:attribute>
        <xsl:attribute name="white-space-treatment">preserve</xsl:attribute>
        <xsl:attribute name="linefeed-treatment">preserve</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="formal.object.properties">
        <xsl:attribute name="space-before.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.maximum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.maximum">0.2em</xsl:attribute>
        <xsl:attribute name="keep-together.within-column">always</xsl:attribute>
    </xsl:attribute-set>
    <xsl:attribute-set name="informal.object.properties">
        <xsl:attribute name="space-before.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-before.maximum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.minimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.optimum">0.2em</xsl:attribute>
        <xsl:attribute name="space-after.maximum">0.2em</xsl:attribute>
    </xsl:attribute-set>    
</xsl:stylesheet>
